async fn rpc_provider(rpc: &RpcOpts) -> Result<(RetryProvider<Ethereum>, u64)>Expand description
Builds the read-only provider for rpc and returns it together with its chain ID.
async fn rpc_provider(rpc: &RpcOpts) -> Result<(RetryProvider<Ethereum>, u64)>Builds the read-only provider for rpc and returns it together with its chain ID.